Module predicate_op

Module predicate_op 

Predicate operators for bytecode.

Extracted from parser for use by both compiler and runtime. The runtime needs to decode predicate operators from bytecode.

Enums

PredicateOp
Predicate operator for node text filtering.