Predicate operators for bytecode.
Extracted from parser for use by both compiler and runtime. The runtime needs to decode predicate operators from bytecode.
Enums
- Predicate
Op - Predicate operator for node text filtering.
Predicate operators for bytecode.
Extracted from parser for use by both compiler and runtime. The runtime needs to decode predicate operators from bytecode.