#[repr(u16)]pub enum PrimitiveType {
Void = 0,
Node = 1,
String = 2,
}Expand description
Primitive type enumeration.
These are the builtin scalar types that don’t require additional metadata in the type table.
Variants
Void = 0
Produces nothing, transparent to parent scope.
Node = 1
A tree-sitter AST node reference.
String = 2
Extracted text from a node.
Implementations
Sourceimpl PrimitiveType
impl PrimitiveType
Sourcepub fn from_index(index: u16) -> Option<Self>
pub fn from_index(index: u16) -> Option<Self>
Try to convert a type index to a primitive type.
Sourcepub fn is_builtin(index: u16) -> bool
pub fn is_builtin(index: u16) -> bool
Check if a type index is a builtin primitive.